"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Cli = void 0;
const tslib_1 = require("tslib");
const commander_1 = require("commander");
const inversify_1 = require("inversify");
const kleur_1 = tslib_1.__importDefault(require("kleur"));
const figlet_1 = tslib_1.__importDefault(require("figlet"));
const types_1 = require("@services/types");
const fs = tslib_1.__importStar(require("fs"));
const path = tslib_1.__importStar(require("path"));
const pkg = require("../../package.json");
let Cli = class Cli {
    lodContentExtractor;
    deckExporter;
    _MINIMUM_ARG_SIZE = 2;
    constructor(lodContentExtractor, deckExporter) {
        this.lodContentExtractor = lodContentExtractor;
        this.deckExporter = deckExporter;
    }
    main(argv) {
        console.log(kleur_1.default.red(figlet_1.default.textSync("LOD to Anki", { horizontalLayout: "full" })));
        const command = new commander_1.Command();
        command.option("-o, --output <directory>", "The output directory", process.cwd());
        command.version(pkg.version, "-v, --version")
            .usage("<command> [options]");
        command.command("extract <lodDump>")
            .description("extract words definitions from LOD dump file")
            .action(async (lodDump) => {
            const lodDumpFile = path.join(process.cwd(), lodDump);
            await this.lodContentExtractor.extract(lodDumpFile, command.opts().output);
        });
        command.command("export <deck>")
            .description("export deck into Anki apkg format")
            .action(async (deckPath) => {
            const deckFile = path.join(process.cwd(), deckPath);
            const deck = JSON.parse(fs.readFileSync(deckFile).toString());
            await this.deckExporter.export(deck, command.opts().output);
        });
        command.parse(argv);
        if (argv.length <= this._MINIMUM_ARG_SIZE) {
            command.help();
        }
    }
};
Cli = tslib_1.__decorate([
    (0, inversify_1.injectable)(),
    tslib_1.__param(0, (0, inversify_1.inject)(types_1.TYPES.LodContentExtractor)),
    tslib_1.__param(1, (0, inversify_1.inject)(types_1.TYPES.DeckExporter)),
    tslib_1.__metadata("design:paramtypes", [Object, Object])
], Cli);
exports.Cli = Cli;
