#!/usr/bin/env node
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.init = void 0;
require("reflect-metadata");
require("module-alias/register");
const inversify_1 = require("inversify");
const cli_1 = require("@controllers/cli");
const types_1 = require("@services/types");
const lod_content_extractor_1 = require("@services/extractors/lod-content-extractor");
const file_writer_1 = require("@services/file-writer");
const word_id_generator_1 = require("@services/word-id-generator");
const noun_extractor_1 = require("@services/extractors/noun-extractor");
const verb_extractor_1 = require("@services/extractors/verb-extractor");
const deck_exporter_1 = require("@services/exporters/deck-exporter");
const label_provider_1 = require("@services/label-provider");
const basic_card_exporter_1 = require("@services/exporters/basic-card-exporter");
const cloze_card_exporter_1 = require("@services/exporters/cloze-card-exporter");
const noun_exporter_1 = require("@services/exporters/noun-exporter");
const verb_exporter_1 = require("@services/exporters/verb-exporter");
const lod_content_exporter_1 = require("@services/exporters/lod-content-exporter");
const preposition_extractor_1 = require("@services/extractors/preposition-extractor");
const base_lod_word_extractor_1 = require("@services/extractors/base-lod-word-extractor");
const base_lod_word_exporter_1 = require("@services/exporters/base-lod-word-exporter");
function init() {
    const container = new inversify_1.Container();
    container.bind(types_1.TYPES.WordIdGenerator).to(word_id_generator_1.WordIdGeneratorImpl).inSingletonScope();
    container.bind(types_1.TYPES.NounExtractor).to(noun_extractor_1.NounExtractorImpl).inSingletonScope();
    container.bind(types_1.TYPES.VerbExtractor).to(verb_extractor_1.VerbExtractorImpl).inSingletonScope();
    container.bind(types_1.TYPES.PrepositionExtractor).to(preposition_extractor_1.PrepositionExtractorImpl).inSingletonScope();
    container.bind(types_1.TYPES.BaseLodWordExtractor).to(base_lod_word_extractor_1.BaseLodWordExtractorImpl).inSingletonScope();
    container.bind(types_1.TYPES.LodContentExtractor).to(lod_content_extractor_1.LodContentExtractorImpl).inSingletonScope();
    container.bind(types_1.TYPES.FileWriter).to(file_writer_1.FileWriterImpl).inSingletonScope();
    container.bind(types_1.TYPES.BaseLodWordExporter).to(base_lod_word_exporter_1.BaseLodWordExporterImpl).inSingletonScope();
    container.bind(types_1.TYPES.BasicCardExporter).to(basic_card_exporter_1.BasicCardExporterImpl).inSingletonScope();
    container.bind(types_1.TYPES.ClozeCardExporter).to(cloze_card_exporter_1.ClozeCardExporterImpl).inSingletonScope();
    container.bind(types_1.TYPES.NounExporter).to(noun_exporter_1.NounExporterImpl).inSingletonScope();
    container.bind(types_1.TYPES.VerbExporter).to(verb_exporter_1.VerbExporterImpl).inSingletonScope();
    container.bind(types_1.TYPES.LodContentExporter).to(lod_content_exporter_1.LodContentExporterImpl).inSingletonScope();
    container.bind(types_1.TYPES.DeckExporter).to(deck_exporter_1.DeckExporterImpl).inSingletonScope();
    container.bind(types_1.TYPES.LabelProvider).to(label_provider_1.LabelProviderImpl).inSingletonScope();
    container.bind(types_1.TYPES.Cli).to(cli_1.Cli).inSingletonScope();
    return container.get(types_1.TYPES.Cli);
}
exports.init = init;
const app = init();
app.main(process.argv);
