"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DeckExporterImpl = void 0;
const tslib_1 = require("tslib");
const inversify_1 = require("inversify");
const fs = tslib_1.__importStar(require("fs"));
const path = tslib_1.__importStar(require("path"));
const types_1 = require("@services/types");
const initSqlJs = require("sql.js");
const { default: AnkiExport } = require("anki-apkg-export/dist/exporter");
const { default: createTemplate } = require("anki-apkg-export/dist/template");
let DeckExporterImpl = class DeckExporterImpl {
    lodContentExporter;
    basicCardExporter;
    clozeCardExporter;
    labelProvider;
    constructor(lodContentExporter, basicCardExporter, clozeCardExporter, labelProvider) {
        this.lodContentExporter = lodContentExporter;
        this.basicCardExporter = basicCardExporter;
        this.clozeCardExporter = clozeCardExporter;
        this.labelProvider = labelProvider;
    }
    async export(deck, outputDirectory) {
        for (const language of deck.languages) {
            const apkg = await this.generateAnki(deck.flashcards, deck.name, language, deck.types, outputDirectory);
            await this.saveAnkiToFile(deck.fileName, language, apkg, outputDirectory);
        }
    }
    async generateAnki(flashcards, deckName, language, types, outputDirectory) {
        const sql = await initSqlJs({});
        const apkg = new AnkiExport(`${deckName} - ${this.labelProvider.get("LANGUAGE", language)}`, {
            template: createTemplate(),
            sql
        });
        const uniqueFlashcards = [...new Set(flashcards)];
        for (const flashcard of uniqueFlashcards) {
            if (flashcard.startsWith("basic:")) {
                this.basicCardExporter.export(apkg, flashcard);
            }
            else if (flashcard.startsWith("cloze:")) {
                this.clozeCardExporter.export(apkg, flashcard);
            }
            else {
                this.lodContentExporter.export(apkg, language, flashcard, types || [], outputDirectory);
            }
        }
        return apkg;
    }
    async saveAnkiToFile(fileName, language, apkg, outputDirectory) {
        const zip = await apkg.save();
        const deckFile = path.join(outputDirectory, `${fileName}_${this.labelProvider.get("LANGUAGE_FILENAME", language)}.apkg`);
        fs.writeFileSync(deckFile, zip, "binary");
    }
};
DeckExporterImpl = tslib_1.__decorate([
    (0, inversify_1.injectable)(),
    tslib_1.__param(0, (0, inversify_1.inject)(types_1.TYPES.LodContentExporter)),
    tslib_1.__param(1, (0, inversify_1.inject)(types_1.TYPES.BasicCardExporter)),
    tslib_1.__param(2, (0, inversify_1.inject)(types_1.TYPES.ClozeCardExporter)),
    tslib_1.__param(3, (0, inversify_1.inject)(types_1.TYPES.LabelProvider)),
    tslib_1.__metadata("design:paramtypes", [Object, Object, Object, Object])
], DeckExporterImpl);
exports.DeckExporterImpl = DeckExporterImpl;
