"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.NounExtractorImpl = void 0;
const tslib_1 = require("tslib");
const inversify_1 = require("inversify");
const types_1 = require("@services/types");
const base_lod_word_extractor_1 = require("./base-lod-word-extractor");
let NounExtractorImpl = class NounExtractorImpl extends base_lod_word_extractor_1.BaseLodWordExtractorImpl {
    constructor(wordIdGenerator) {
        super(wordIdGenerator);
    }
    extractDetails(lodWordType, structure) {
        const { variationOfLodKey, variationType } = this.extractVariantOf(lodWordType, structure);
        return {
            nounGender: this.extractGender(structure),
            nounCategory: this.extractNounCategory(structure),
            plural: this.extractPlural(structure),
            variationOfLodKey: variationOfLodKey,
            variationType: variationType
        };
    }
    extractGender(structure) {
        return structure["lod:GENRE"][0]["attributes"]["lod:GEN"].trim();
    }
    extractNounCategory(structure) {
        const attributes = structure["lod:CAT-GRAM-SUBST"][0]["attributes"];
        if (!!attributes) {
            return attributes["lod:C-G-SUBST"].trim();
        }
        return undefined;
    }
    extractPlural(structure) {
        let plural;
        const pluralType = Object.keys(structure["lod:PLURIEL"][0])[1];
        const pluralStructure = structure["lod:PLURIEL"][0][pluralType];
        switch (pluralType) {
            case "lod:TJ-NOMBRABLE":
            case "lod:ALT-MASSIF-NOMBRABLE":
                const pluralObj = pluralStructure[0]["lod:FORME-PLURIEL"][0];
                if ((!!pluralObj) && (pluralObj.constructor === Object)) {
                    plural = pluralObj["_"].trim();
                }
                else {
                    plural = pluralObj.trim();
                }
                break;
            case "lod:PLURALE-TANTUM":
            case "lod:TJ-MASSIF":
            case "lod:SITUATION-PLURIEL-COMPLEXE":
                plural = undefined;
                break;
            default: throw new Error(`${pluralType} not recognized.`);
        }
        return plural;
    }
};
NounExtractorImpl = tslib_1.__decorate([
    (0, inversify_1.injectable)(),
    tslib_1.__param(0, (0, inversify_1.inject)(types_1.TYPES.WordIdGenerator)),
    tslib_1.__metadata("design:paramtypes", [Object])
], NounExtractorImpl);
exports.NounExtractorImpl = NounExtractorImpl;
