"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PrepositionExtractorImpl = void 0;
const tslib_1 = require("tslib");
const inversify_1 = require("inversify");
const types_1 = require("@services/types");
const base_lod_word_extractor_1 = require("./base-lod-word-extractor");
let PrepositionExtractorImpl = class PrepositionExtractorImpl extends base_lod_word_extractor_1.BaseLodWordExtractorImpl {
    constructor(wordIdGenerator) {
        super(wordIdGenerator);
    }
    extractMeaningsFromStructure(word, meaningStructure) {
        const meanings = [];
        const translationUnitStructures = meaningStructure["lod:UNITE-TRAD"];
        for (const translationUnitStructure of translationUnitStructures) {
            const translationStructures = translationUnitStructure["lod:PAS-DE-TRAD-SUBORDONNANTE"];
            for (const translationStructure of translationStructures) {
                const translation = translationStructure["lod:UNITE-DE-SENS"][0];
                meanings.push({
                    examples: this.extractExamples(word, translation),
                    synonyms: this.extractSynonyms(translation),
                    polyLex: this.extractPolyLex(translation),
                    case: this.extractCase(meaningStructure),
                    translations: [
                        this.extractTranslation("ALL", translation),
                        this.extractTranslation("FR", translation),
                        this.extractTranslation("PO", translation),
                        this.extractTranslation("EN", translation)
                    ]
                });
            }
        }
        return meanings;
    }
    extractCase(meaningStructure) {
        return meaningStructure["lod:CAS-ATTENDU"][0]["attributes"]["lod:CAS"];
    }
};
PrepositionExtractorImpl = tslib_1.__decorate([
    (0, inversify_1.injectable)(),
    tslib_1.__param(0, (0, inversify_1.inject)(types_1.TYPES.WordIdGenerator)),
    tslib_1.__metadata("design:paramtypes", [Object])
], PrepositionExtractorImpl);
exports.PrepositionExtractorImpl = PrepositionExtractorImpl;
