"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.VerbExtractorImpl = void 0;
const tslib_1 = require("tslib");
const inversify_1 = require("inversify");
const types_1 = require("@services/types");
const base_lod_word_extractor_1 = require("./base-lod-word-extractor");
let VerbExtractorImpl = class VerbExtractorImpl extends base_lod_word_extractor_1.BaseLodWordExtractorImpl {
    constructor(wordIdGenerator) {
        super(wordIdGenerator);
    }
    extractDetails(lodWordType, structure) {
        const { variationOfLodKey, variationType } = this.extractVariantOf(lodWordType, structure);
        return {
            variationOfLodKey: variationOfLodKey,
            variationType: variationType,
            auxiliaryVerb: this.extractAuxiliaryVerb(structure),
            pastParticiples: this.extractPastParticiples(structure),
            verbCategory: this.extractVerbCategory(structure)
        };
    }
    extractAuxiliaryVerb(structure) {
        let auxiliaryVerb = undefined;
        const auxiliaryVerbStructure = structure["lod:VRB-AUXILIAIRE"];
        if (!!auxiliaryVerbStructure) {
            auxiliaryVerb = auxiliaryVerbStructure[0]["attributes"]["lod:AUXIL"];
        }
        return auxiliaryVerb;
    }
    extractPastParticiples(structure) {
        return structure["lod:PARTICIPE-PASSE"];
    }
    extractVerbCategory(structure) {
        let verbCategory = undefined;
        const verbCategoryStructure = structure["lod:CAT-GRAM-VRB"][0]["attributes"];
        if (!!verbCategoryStructure) {
            verbCategory = verbCategoryStructure["lod:C-G-VRB"];
        }
        return verbCategory;
    }
    extractMeaningsFromStructure(word, meaningStructure) {
        const meanings = [];
        const translationUnitStructures = meaningStructure["lod:UNITE-TRAD"];
        for (const translationUnitStructure of translationUnitStructures) {
            const translationStructures = translationUnitStructure["lod:PAS-DE-TRAD-SUBORDONNANTE"];
            for (const translationStructure of translationStructures) {
                const translation = translationStructure["lod:UNITE-DE-SENS"][0];
                meanings.push({
                    examples: this.extractExamples(word, translation),
                    synonyms: this.extractSynonyms(translation),
                    polyLex: this.extractPolyLex(translation),
                    reflexivePronoun: this.extractReflexivePronoum(meaningStructure),
                    employsImpersonal: this.extractImpersonalPronoum(meaningStructure),
                    translations: [
                        this.extractTranslation("ALL", translation),
                        this.extractTranslation("FR", translation),
                        this.extractTranslation("PO", translation),
                        this.extractTranslation("EN", translation)
                    ]
                });
            }
        }
        return meanings;
    }
    extractReflexivePronoum(meaningStructure) {
        return meaningStructure["lod:REFLEX-PRONOM"][0]["attributes"]["lod:REFPRON"];
    }
    extractImpersonalPronoum(meaningStructure) {
        return meaningStructure["lod:EMPLOI-IMPERS"][0]["attributes"]["lod:EMPLOI-IMPERS"];
    }
};
VerbExtractorImpl = tslib_1.__decorate([
    (0, inversify_1.injectable)(),
    tslib_1.__param(0, (0, inversify_1.inject)(types_1.TYPES.WordIdGenerator)),
    tslib_1.__metadata("design:paramtypes", [Object])
], VerbExtractorImpl);
exports.VerbExtractorImpl = VerbExtractorImpl;
